@@ -262,30 +262,29 @@ make_fays_gen_rep_factors <- function(
 #' detailed description of each variance estimator.
 #' Options include:
 #' \itemize{
-#'   \item{\strong{"Yates-Grundy"}: }{The Yates-Grundy variance estimator based on
-#'   first-order and second-order inclusion probabilities.}
-#'   \item{\strong{"Horvitz-Thompson"}: }{The Horvitz-Thompson variance estimator based on
-#'   first-order and second-order inclusion probabilities.}
-#'   \item{\strong{"Poisson Horvitz-Thompson"}: }{The Horvitz-Thompson variance estimator
-#'   based on assuming Poisson sampling, with first-order inclusion probabilities
-#'   inferred from the sampling probabilities of the survey design object.}
-#'   \item{\strong{"Stratified Multistage SRS"}: }{The usual stratified multistage variance estimator
-#'   based on estimating the variance of cluster totals within strata at each stage.}
-#'   \item{\strong{"Ultimate Cluster"}: }{The usual variance estimator based on estimating
-#'   the variance of first-stage cluster totals within first-stage strata.}
-#'   \item{\strong{"Deville-1"}: }{A variance estimator for unequal-probability
-#'   sampling without replacement, described in Matei and Tillé (2005)
-#'   as "Deville 1".}
-#'   \item{\strong{"Deville-2"}: }{A variance estimator for unequal-probability
-#'   sampling without replacement, described in Matei and Tillé (2005)
-#'   as "Deville 2".}
-#'   \item{\strong{"Deville-Tille": }}{A variance estimator useful
-#'   for balanced sampling designs, proposed by Deville and Tillé (2005).}
-#'   \item{\strong{"SD1"}: }{The non-circular successive-differences variance estimator described by Ash (2014),
-#'   sometimes used for variance estimation for systematic sampling.}
-#'   \item{\strong{"SD2"}: }{The circular successive-differences variance estimator described by Ash (2014).
-#'   This estimator is the basis of the "successive-differences replication" estimator commonly used
-#'   for variance estimation for systematic sampling.}
+#'   \item \strong{"Yates-Grundy"}: \cr The Yates-Grundy variance estimator based on
+#'     first-order and second-order inclusion probabilities.
+#'   \item \strong{"Horvitz-Thompson"}: \cr The Horvitz-Thompson variance estimator based on
+#'     first-order and second-order inclusion probabilities.
+#'   \item \strong{"Poisson Horvitz-Thompson"}: \cr The Horvitz-Thompson variance estimator
+#'     based on assuming Poisson sampling, with first-order inclusion probabilities
+#'     inferred from the sampling probabilities of the survey design object.
+#'   \item \strong{"Stratified Multistage SRS"}: \cr The usual stratified multistage variance estimator
+#'     based on estimating the variance of cluster totals within strata at each stage.
+#'   \item \strong{"Ultimate Cluster"}: \cr The usual variance estimator based on estimating
+#'     the variance of first-stage cluster totals within first-stage strata.
+#'   \item \strong{"Deville-1"}: \cr A variance estimator for unequal-probability
+#'     sampling without replacement, described in Matei and Tillé (2005)
+#'     as "Deville 1".
+#'   \item \strong{"Deville-2"}: \cr A variance estimator for unequal-probability
+#'     sampling without replacement, described in Matei and Tillé (2005) as "Deville 2".
+#'   \item \strong{"Deville-Tille": } \cr A variance estimator useful
+#'     for balanced sampling designs, proposed by Deville and Tillé (2005).
+#'   \item \strong{"SD1"}: \cr The non-circular successive-differences variance estimator described by Ash (2014),
+#'     sometimes used for variance estimation for systematic sampling.
+#'   \item\strong{"SD2"}:  \cr The circular successive-differences variance estimator described by Ash (2014).
+#'     This estimator is the basis of the "successive-differences replication" estimator commonly used
+#'     for variance estimation for systematic sampling.
 #' }
 #' @param aux_var_names (Only used if \code{variance_estimator = "Deville-Tille")}.
 #' A vector of the names of auxiliary variables used in sampling.
@@ -314,8 +313,10 @@ make_fays_gen_rep_factors <- function(
 #' for details of the approximation.
 #' @param compress This reduces the computer memory required to represent the replicate weights and has no
 #' impact on estimates.
-#' @param mse If \code{TRUE}, compute variances from sums of squares around the point estimate from the full-sample weights,
+#' @param mse If \code{TRUE} (the default), compute variances from sums of squares around the point estimate from the full-sample weights,
 #' If \code{FALSE}, compute variances from sums of squares around the mean estimate from the replicate weights.
+#' For Fay's generalized replication method, setting \code{mse = FALSE} can potentially
+#' lead to large underestimates of variance.
 #' @return
 #' A replicate design object, with class \code{svyrep.design}, which can be used with the usual functions,
 #' such as \code{svymean()} or \code{svyglm()}.
@@ -415,8 +416,13 @@ as_fays_gen_rep_design <- function(design, variance_estimator = NULL,
                                    max_replicates = 500,
                                    balanced = TRUE,
                                    psd_option = "warn",
-                                   mse = getOption("survey.replicates.mse"),
+                                   mse = TRUE,
                                    compress = TRUE) {
+  
+  if (!mse) {
+    warning("When `balanced = FALSE`, setting `mse = FALSE` may produce large underestimates of variance.")
+  }
+  
   UseMethod("as_fays_gen_rep_design", design)
 }
 
@@ -490,8 +496,9 @@ as_fays_gen_rep_design.survey.design <- function(design, variance_estimator = NU
                                                  max_replicates = 500,
                                                  balanced = TRUE,
                                                  psd_option = 'warn',
-                                                 mse = getOption("survey.replicates.mse"),
+                                                 mse = TRUE,
                                                  compress = TRUE) {
+  
 
   # Produce a (potentially) compressed survey design object
   compressed_design_structure <- compress_design(design, vars_to_keep = aux_var_names)
@@ -573,7 +580,7 @@ as_fays_gen_rep_design.DBIsvydesign <- function(design, variance_estimator = NUL
                                                 max_replicates = 500,
                                                 balanced = TRUE,
                                                 psd_option = 'warn',
-                                                mse = getOption("survey.replicates.mse"),
+                                                mse = TRUE,
                                                 compress = TRUE) {
 
   # Produce a (potentially) compressed survey design object
