@@ -400,10 +400,10 @@ test_that(
     })
 
     rescaled_design <- twophase_gen_repl |>
-      rescale_reps(tau = "auto", min_wgt = 0.05)
+      rescale_reps(tau = NULL, min_wgt = 0.05)
     rescaled_matrix <- twophase_gen_repl |>
       weights(type = "replication") |>
-      rescale_reps(tau = "auto", min_wgt = 0.05)
+      rescale_reps(tau = NULL, min_wgt = 0.05)
 
     expect_equal(
       object = rescaled_design |> weights(type = "replication"),
@@ -503,6 +503,18 @@ test_that(
   }
 )
 
+# Warnings for ill-advised choices -----
+
+test_that(
+  desc = "Warning when `mse = FALSE`", {
+    expect_warning({
+    twophase_design$phase1$full |> 
+      as_fays_gen_rep_design("Ultimate Cluster", mse = FALSE) |>
+      svytotal(x = ~ y1)
+    }, regexp = "may produce large underestimates")
+  }
+)
+
 # Works for more specialized classes of survey designs ----
 
 test_that(
